==> xoops-2.4.5-rc3.zip: xoops-2.4.5-rc3/htdocs/modules/system/language/english/blocks.php <==
<?php
// $Id: blocks.php 2411 2008-11-14 21:01:07Z julionc $
// _LANGCODE: en
// _CHARSET : UTF-8
// Translator: XOOPS Translation Team

// Blocks
define("_MB_SYSTEM_ADMENU","Administration Menu");
define("_MB_SYSTEM_RNOW","Register now!");
define("_MB_SYSTEM_LPASS","Lost Password?");
define("_MB_SYSTEM_SEARCH","Search");
define("_MB_SYSTEM_ADVS","Advanced Search");
define("_MB_SYSTEM_VACNT","View Account");
define("_MB_SYSTEM_EACNT","Edit Account");
// RMV-NOTIFY
define("_MB_SYSTEM_NOTIF", "Notifications");
define("_MB_SYSTEM_LOUT","Logout");
define("_MB_SYSTEM_INBOX","Inbox");
define("_MB_SYSTEM_SUBMS","Submitted News");
define("_MB_SYSTEM_WLNKS","Waiting Links");
define("_MB_SYSTEM_BLNK","Broken Links");
define("_MB_SYSTEM_MLNKS","Modified Links");
define("_MB_SYSTEM_WDLS","Waiting Downloads");
define("_MB_SYSTEM_BFLS","Broken Files");
define("_MB_SYSTEM_MFLS","Modified Downloads");
define("_MB_SYSTEM_HOME","Home"); // link to home page in main menu block
define("_MB_SYSTEM_RECO","Recommend Us");
define("_MB_SYSTEM_PWWIDTH","Pop-Up Window Width");
define("_MB_SYSTEM_PWHEIGHT","Pop-Up Window Height");
define("_MB_SYSTEM_LOGO","Logo image file under %s directory");  // %s is your root image directory name
define("_MB_SYSTEM_COMPEND", "Comments");

//define("_MB_SYSTEM_LOGGEDINAS", "Logged in as");
define("_MB_SYSTEM_SADMIN","Show admin groups");
define("_MB_SYSTEM_SPMTO","Send Private Message to %s");
define("_MB_SYSTEM_SEMTO","Send Email to %s");

define("_MB_SYSTEM_DISPLAY","Display %s members");
define("_MB_SYSTEM_DISPLAYA","Display member avatars");
define("_MB_SYSTEM_NODISPGR","Do not display users whose rank is:");

define("_MB_SYSTEM_DISPLAYC","Display %s comments");
define("_MB_SYSTEM_SECURE", "Secure Login");

define("_MB_SYSTEM_NUMTHEME", "%s themes");
define("_MB_SYSTEM_THSHOW", "Display screenshot image");
define("_MB_SYSTEM_THWIDTH", "Screenshot image width");
define('_MB_SYSTEM_REMEMBERME', 'Remember me');

?>

==> xoops-2.5.0.zip: xoops-2.5.0/htdocs/modules/system/language/english/blocks.php <==
<?php
// $Id: blocks.php 5566 2010-10-20 11:45:26Z beckmi $
// _LANGCODE: en
// _CHARSET : UTF-8
// Translator: XOOPS Translation Team

// Blocks
define("_MB_SYSTEM_ADMENU","Administration Menu");
define("_MB_SYSTEM_RNOW","Register now!");
define("_MB_SYSTEM_LPASS","Lost Password?");
define("_MB_SYSTEM_SEARCH","Search");
define("_MB_SYSTEM_ADVS","Advanced Search");
define("_MB_SYSTEM_VACNT","View Account");
define("_MB_SYSTEM_EACNT","Edit Account");
// RMV-NOTIFY
define("_MB_SYSTEM_NOTIF", "Notifications");
define("_MB_SYSTEM_LOUT","Logout");
define("_MB_SYSTEM_INBOX","Inbox");
define("_MB_SYSTEM_SUBMS","Submitted News");
define("_MB_SYSTEM_WLNKS","Waiting Links");
define("_MB_SYSTEM_BLNK","Broken Links");
define("_MB_SYSTEM_MLNKS","Modified Links");
define("_MB_SYSTEM_WDLS","Waiting Downloads");
define("_MB_SYSTEM_BFLS","Broken Files");
define("_MB_SYSTEM_MFLS","Modified Downloads");
define("_MB_SYSTEM_TDMDOWNLOADS","Waiting Downloads");
define("_MB_SYSTEM_EXTGALLERY","Waiting Photos");
define("_MB_SYSTEM_SMARTSECTION","Articles");
define("_MB_SYSTEM_HOME","Home"); // link to home page in main menu block
define("_MB_SYSTEM_RECO","Recommend Us");
define("_MB_SYSTEM_PWWIDTH","Pop-Up Window Width");
define("_MB_SYSTEM_PWHEIGHT","Pop-Up Window Height");
define("_MB_SYSTEM_LOGO","Logo image file under %s directory");  // %s is your root image directory name
define("_MB_SYSTEM_COMPEND", "Comments");

//define("_MB_SYSTEM_LOGGEDINAS", "Logged in as");
define("_MB_SYSTEM_SADMIN","Show admin groups");
define("_MB_SYSTEM_SPMTO","Send Private Message to %s");
define("_MB_SYSTEM_SEMTO","Send Email to %s");

define("_MB_SYSTEM_DISPLAY","Display %s members");
define("_MB_SYSTEM_DISPLAYA","Display member avatars");
define("_MB_SYSTEM_NODISPGR","Do not display users whose rank is:");

define("_MB_SYSTEM_DISPLAYC","Display %s comments");
define("_MB_SYSTEM_SECURE", "Secure Login");

define("_MB_SYSTEM_NUMTHEME", "%s themes");
define("_MB_SYSTEM_THSHOW", "Display screenshot image");
define("_MB_SYSTEM_THWIDTH", "Screenshot image width");
define("_MB_SYSTEM_REMEMBERME","Remember me");

?>
